@@ -168,8 +168,8 @@ static bool _lf_parse_lens_name (const char *model,
 
 void lfLens::GuessParameters ()
 {
-    float minf = INT_MAX, maxf = INT_MIN;
-    float mina = INT_MAX, maxa = INT_MIN;
+    float minf = float (INT_MAX), maxf = float (INT_MIN);
+    float mina = float (INT_MAX), maxa = float (INT_MIN);
 
     char *old_numeric = setlocale (LC_NUMERIC, "C");
 
@@ -246,18 +246,18 @@ const char *lfLens::GetDistortionModelDesc (
 {
     static const lfParameter *param_none [] = { NULL };
 
-    static const lfParameter param_poly3_k1 = { "k1", -0.2, 0.2, 0.0 };
+    static const lfParameter param_poly3_k1 = { "k1", -0.2F, 0.2F, 0.0F };
     static const lfParameter *param_poly3 [] = { &param_poly3_k1, NULL };
 
-    static const lfParameter param_poly5_k2 = { "k2", -0.2, 0.2, 0.0 };
+    static const lfParameter param_poly5_k2 = { "k2", -0.2F, 0.2F, 0.0F };
     static const lfParameter *param_poly5 [] = { &param_poly3_k1, &param_poly5_k2, NULL };
 
-    static const lfParameter param_fov1_omega = { "omega", 0.0, 1.4, 0.0 };
+    static const lfParameter param_fov1_omega = { "omega", 0.0F, 1.4F, 0.0F };
     static const lfParameter *param_fov1 [] = { &param_fov1_omega, NULL };
 
-    static const lfParameter param_ptlens_a = { "a", -0.2, 0.2, 0.0 };
-    static const lfParameter param_ptlens_b = { "b", -0.2, 0.2, 0.0 };
-    static const lfParameter param_ptlens_c = { "c", -0.2, 0.2, 0.0 };
+    static const lfParameter param_ptlens_a = { "a", -0.2F, 0.2F, 0.0F };
+    static const lfParameter param_ptlens_b = { "b", -0.2F, 0.2F, 0.0F };
+    static const lfParameter param_ptlens_c = { "c", -0.2F, 0.2F, 0.0F };
     static const lfParameter *param_ptlens [] = {
         &param_ptlens_a, &param_ptlens_b, &param_ptlens_c, NULL };
 
@@ -301,6 +301,10 @@ const char *lfLens::GetDistortionModelDesc (
             if (params)
                 *params = param_ptlens;
             return "PanoTools lens model";
+
+        default:
+            // keep gcc 4.4 happy
+            break;
     }
 
     if (details)
@@ -315,8 +319,8 @@ const char *lfLens::GetTCAModelDesc (
 {
     static const lfParameter *param_none [] = { NULL };
 
-    static const lfParameter param_linear_kr = { "kr", 0.99, 1.01, 1.0 };
-    static const lfParameter param_linear_kb = { "kb", 0.99, 1.01, 1.0 };
+    static const lfParameter param_linear_kr = { "kr", 0.99F, 1.01F, 1.0F };
+    static const lfParameter param_linear_kb = { "kb", 0.99F, 1.01F, 1.0F };
     static const lfParameter *param_linear [] =
     { &param_linear_kr, &param_linear_kb, NULL };
 
@@ -328,6 +332,7 @@ const char *lfLens::GetTCAModelDesc (
             if (params)
                 *params = param_none;
             return "None";
+
         case LF_TCA_MODEL_LINEAR:
             if (details)
                 *details = "Rd = Ru * k\n"
@@ -335,6 +340,10 @@ const char *lfLens::GetTCAModelDesc (
             if (params)
                 *params = param_linear;
             return "Linear";
+
+        default:
+            // keep gcc 4.4 happy
+            break;
     }
 
     if (details)
@@ -363,6 +372,7 @@ const char *lfLens::GetVignettingModelDesc (
             if (params)
                 *params = param_none;
             return "None";
+
         case LF_VIGNETTING_MODEL_PA:
             if (details)
                 *details = "Pablo D'Angelo vignetting model\n"
@@ -372,6 +382,10 @@ const char *lfLens::GetVignettingModelDesc (
             if (params)
                 *params = param_pa;
             return "6th order polynomial";
+
+        default:
+            // keep gcc 4.4 happy
+            break;
     }
 
     if (details)
@@ -389,22 +403,30 @@ const char *lfLens::GetLensTypeDesc (lfLensType type, const char **details)
             if (details)
                 *details = "";
             return "Unknown";
+
         case LF_RECTILINEAR:
             if (details)
                 *details = "Ref: http://wiki.panotools.org/Rectilinear_Projection";
             return "Rectilinear";
+
         case LF_FISHEYE:
             if (details)
                 *details = "Ref: http://wiki.panotools.org/Fisheye_Projection";
             return "Fish-Eye";
+
         case LF_PANORAMIC:
             if (details)
                 *details = "Ref: http://wiki.panotools.org/Cylindrical_Projection";
             return "Panoramic";
+
         case LF_EQUIRECTANGULAR:
             if (details)
                 *details = "Ref: http://wiki.panotools.org/Equirectangular_Projection";
             return "Equirectangular";
+
+        default:
+            // keep gcc 4.4 happy
+            break;
     }
 
     if (details)
@@ -755,7 +777,7 @@ bool lfLens::InterpolateVignetting (
 
     lfVignettingModel vm = LF_VIGNETTING_MODEL_NONE;
 
-    float min_dist = 0.01;
+    float min_dist = 0.01F;
     for (guint i = 0; i < vc->len; i++)
     {
         lfLensCalibVignetting *c =
@@ -839,14 +861,17 @@ bool lfLens::InterpolateVignetting (
                 case 0:
                     spline_dist [0] = dist;
                     break;
+
                 case 1:
                     spline_dist [0] = spline_dist [1];
                     spline_dist [1] = dist;
                     break;
+
                 case 2:
                     spline_dist [3] = spline_dist [2];
                     spline_dist [2] = dist;
                     break;
+
                 case 3:
                     spline_dist [3] = dist;
                     break;
@@ -1032,6 +1057,7 @@ int _lf_lens_compare_score (const lfLens *pattern, const lfLens *match,
     {
         case -1:
             return 0;
+
         case +1:
             score += 10;
             break;
@@ -1041,6 +1067,7 @@ int _lf_lens_compare_score (const lfLens *pattern, const lfLens *match,
     {
         case -1:
             return 0;
+
         case +1:
             score += 10;
             break;
