@@ -9,10 +9,12 @@
 #include "config.h"
 #include "lensfun.h"
 #include "lensfunprv.h"
+
+#define _USE_MATH_DEFINES // f*k microsoft
 #include <math.h>
 
 // This epsilon is in image coordinate space, where 1.0 is
-// half of the smallest image dimenstion (width or height)
+// half of the smallest image dimension (width or height)
 // adjusted for the lens calibration data/camera crop factors.
 #define NEWTON_EPS 0.00001
 
@@ -38,11 +40,13 @@ bool lfModifier::AddCoordCallbackDistortion (lfLensCalibDistortion &model, bool
                 tmp [0] = 1.0 / model.Terms [0];
                 AddCoordCallback (lfExtModifier::ModifyCoord_Dist_Poly3, 750, tmp, sizeof (float));
                 break;
+
             case LF_DIST_MODEL_POLY5:
                 tmp [0] = model.Terms [0];
                 tmp [1] = model.Terms [1];
                 AddCoordCallback (lfExtModifier::ModifyCoord_Dist_Poly5, 750, tmp, sizeof (float) * 2);
                 break;
+
             case LF_DIST_MODEL_FOV1:
                 if (!model.Terms [0])
                     return false;
@@ -50,12 +54,14 @@ bool lfModifier::AddCoordCallbackDistortion (lfLensCalibDistortion &model, bool
                 tmp [1] = 2.0 * tan (model.Terms [0] / 2.0);
                 AddCoordCallback (lfExtModifier::ModifyCoord_Dist_FOV1, 750, tmp, sizeof (float) * 2);
                 break;
+
             case LF_DIST_MODEL_PTLENS:
                 tmp [0] = model.Terms [0];
                 tmp [1] = model.Terms [1];
                 tmp [2] = model.Terms [2];
                 AddCoordCallback (lfExtModifier::ModifyCoord_Dist_PTLens, 750, tmp, sizeof (float) * 2);
                 break;
+
             default:
                 return false;
         }
@@ -66,11 +72,13 @@ bool lfModifier::AddCoordCallbackDistortion (lfLensCalibDistortion &model, bool
                 tmp [0] = model.Terms [0];
                 AddCoordCallback (lfExtModifier::ModifyCoord_UnDist_Poly3, 250, tmp, sizeof (float));
                 break;
+
             case LF_DIST_MODEL_POLY5:
                 tmp [0] = model.Terms [0];
                 tmp [1] = model.Terms [1];
                 AddCoordCallback (lfExtModifier::ModifyCoord_UnDist_Poly5, 250, tmp, sizeof (float) * 2);
                 break;
+
             case LF_DIST_MODEL_FOV1:
                 if (!model.Terms [0])
                     return false;
@@ -78,12 +86,14 @@ bool lfModifier::AddCoordCallbackDistortion (lfLensCalibDistortion &model, bool
                 tmp [1] = 0.5 / tan (model.Terms [0] / 2.0);
                 AddCoordCallback (lfExtModifier::ModifyCoord_UnDist_FOV1, 250, tmp, sizeof (float) * 2);
                 break;
+
             case LF_DIST_MODEL_PTLENS:
                 tmp [0] = model.Terms [0];
                 tmp [1] = model.Terms [1];
                 tmp [2] = model.Terms [2];
                 AddCoordCallback (lfExtModifier::ModifyCoord_UnDist_PTLens, 250, tmp, sizeof (float) * 3);
                 break;
+
             default:
                 return false;
         }
@@ -100,22 +110,22 @@ float lfModifier::GetAutoScale (bool reverse)
     // 5 6 7
     struct { float angle, dist; } edge [8];
 
-    edge [1].angle = atan2 (This->Height, This->Width);
+    edge [1].angle = atan2 (float (This->Height), float (This->Width));
     edge [3].angle = M_PI - edge [1].angle;
     edge [5].angle = M_PI + edge [1].angle;
     edge [7].angle = 2 * M_PI - edge [1].angle;
 
-    edge [0].angle = 0.0;
-    edge [2].angle = M_PI / 2.0;
-    edge [4].angle = M_PI;
-    edge [6].angle = M_PI * 3.0 / 2.0;
+    edge [0].angle = 0.0F;
+    edge [2].angle = float (M_PI / 2.0);
+    edge [4].angle = float (M_PI);
+    edge [6].angle = float (M_PI * 3.0 / 2.0);
 
     edge [1].dist = edge [3].dist = edge [5].dist = edge [7].dist =
-        sqrt (This->Width * This->Width + This->Height * This->Height) * 0.5 * This->NormScale;
+        sqrt (float (square (This->Width) + square (This->Height))) * 0.5 * This->NormScale;
     edge [0].dist = edge [4].dist = This->Width * 0.5 * This->NormScale;
     edge [2].dist = edge [6].dist = This->Height * 0.5 * This->NormScale;
 
-    float scale = 0.01;
+    float scale = 0.01F;
     for (int i = 0; i < 8; i++)
     {
         float angle = edge [i].angle;
@@ -127,7 +137,7 @@ float lfModifier::GetAutoScale (bool reverse)
         // We will use Newton's method for this, we have to find the
         // root of the equation: distance (distorted (x,y)) - dist = 0
         float ru = dist; // Initial approximation
-        float dx = 0.0001;
+        float dx = 0.0001F;
         for (int countdown = 50; ; countdown--)
         {
             float res [2];
@@ -219,21 +229,29 @@ bool lfModifier::AddCoordCallbackGeometry (lfLensType from, lfLensType to, float
                 case LF_UNKNOWN:
                     // Should never happen
                     return false;
+
                 case LF_RECTILINEAR:
                     // Nothing to do
                     return false;
+
                 case LF_FISHEYE:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_Rect_FishEye,
                                       500, tmp, sizeof (tmp));
                     return true;
+
                 case LF_PANORAMIC:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_Rect_Panoramic,
                                       500, tmp, sizeof (tmp));
                     return true;
+
                 case LF_EQUIRECTANGULAR:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_Rect_ERect,
                                       500, tmp, sizeof (tmp));
                     return true;
+
+                default:
+                    // keep gcc 4.4+ happy
+                    break;
             }
             break;
 
@@ -243,21 +261,29 @@ bool lfModifier::AddCoordCallbackGeometry (lfLensType from, lfLensType to, float
                 case LF_UNKNOWN:
                     // Should never happen
                     return false;
+
                 case LF_RECTILINEAR:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_FishEye_Rect,
                                       500, tmp, sizeof (tmp));
                     return true;
+
                 case LF_FISHEYE:
                     // Nothing to do
                     return false;
+
                 case LF_PANORAMIC:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_FishEye_Panoramic,
                                       500, tmp, sizeof (tmp));
                     return true;
+
                 case LF_EQUIRECTANGULAR:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_FishEye_ERect,
                                       500, tmp, sizeof (tmp));
                     return true;
+
+                default:
+                    // keep gcc 4.4+ happy
+                    break;
             }
             break;
 
@@ -267,21 +293,29 @@ bool lfModifier::AddCoordCallbackGeometry (lfLensType from, lfLensType to, float
                 case LF_UNKNOWN:
                     // Should never happen
                     return false;
+
                 case LF_RECTILINEAR:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_Panoramic_Rect,
                                       500, tmp, sizeof (tmp));
                     return true;
+
                 case LF_FISHEYE:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_Panoramic_FishEye,
                                       500, tmp, sizeof (tmp));
                     return true;
+
                 case LF_PANORAMIC:
                     // Nothing to do
                     return false;
+
                 case LF_EQUIRECTANGULAR:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_Panoramic_ERect,
                                       500, tmp, sizeof (tmp));
                     return true;
+
+                default:
+                    // keep gcc 4.4+ happy
+                    break;
             }
             break;
 
@@ -291,21 +325,29 @@ bool lfModifier::AddCoordCallbackGeometry (lfLensType from, lfLensType to, float
                 case LF_UNKNOWN:
                     // Should never happen
                     return false;
+
                 case LF_RECTILINEAR:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_ERect_Rect,
                                       500, tmp, sizeof (tmp));
                     return true;
+
                 case LF_FISHEYE:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_ERect_FishEye,
                                       500, tmp, sizeof (tmp));
                     return true;
+
                 case LF_PANORAMIC:
                     AddCoordCallback (lfExtModifier::ModifyCoord_Geom_ERect_Panoramic,
                                       500, tmp, sizeof (tmp));
                     return true;
+
                 case LF_EQUIRECTANGULAR:
                     // Nothing to do
                     return false;
+
+                default:
+                    // keep gcc 4.4+ happy
+                    break;
             }
             break;
     }
@@ -602,7 +644,7 @@ void lfExtModifier::ModifyCoord_Geom_Rect_FishEye (void *data, float *iocoord, i
         float rho, theta = r * inv_dist;
 
         if (theta >= M_PI / 2.0)
-            rho = 1.6e16;
+            rho = 1.6e16F;
         else if (theta == 0.0)
             rho = 1.0;
         else
